<?php

namespace plugin\inspection\controller\api\auth;

use plugin\inspection\controller\api\Auth;
use plugin\inspection\model\InspectionRecord;
use plugin\ticket\model\TicketTicket;

class Record extends Auth
{
    public function index()
    {
        $query = $this->staff->records();
        $status = $this->request->get('status');
        if (is_numeric($status)) {
            $query->where('status', $status);
        }
        $pageData = $query->order('create_at desc')->paginate();
        $this->success('获取记录成功', $pageData);
    }

    public function info()
    {
        $record_id = $this->request->get('record_id');
        $record = InspectionRecord::mk()->where('id', $record_id)->with(['points'])->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $this->success('获取记录成功', $record);
    }

    public function create()
    {
        $record = $this->staff->records()->save([
            'no' => uniqid('XJ_' . date('YmdHis')),
            'create_at' => date('Y-m-d H:i:s'),
            'status' => 0,
        ]);
        $this->success('创建记录成功', $record);
    }

    public function end()
    {
        $result = $this->_vali([
            'record_id.require' => '记录ID不能为空',
            'record_id.integer' => '记录ID必须是整数',
            'content.require' => '记录内容不能为空',
            'imgs.require' => '记录图片不能为空'
        ]);
        $record = InspectionRecord::mk()->where('id', $result['record_id'])->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $lat = $this->request->post('lat');
        $lng = $this->request->post('lng');
        if ($lat != 0 || $lng != 0) {
            $record->points()->save([
                'staff_id' => $this->staff->id,
                'lat' => $lat,
                'lng' => $lng,
                'is_pause' => 1,
                'create_at' => date('Y-m-d H:i:s'),
            ]);
        }
        $record->status = 1;
        $record->imgs = $result['imgs'];
        $record->content = $result['content'];
        $record->end_at = date('Y-m-d H:i:s');
        $record->save();
        $record->autoFix();
        $this->success('结束记录成功');
    }

    public function add_point()
    {
        $record_id = $this->request->post('record_id');
        $lat = $this->request->post('lat');
        $lng = $this->request->post('lng');
        /** @var InspectionRecord $record */
        $record = InspectionRecord::query()->where('id', $record_id)->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        if ($lat != 0 || $lng != 0) {
            $point = $record->points()->save([
                'staff_id' => $this->staff->id,
                'is_pause' => $this->request->post('is_pause', 0),
                'lat' => $lat,
                'lng' => $lng,
                'create_at' => date('Y-m-d H:i:s'),
            ]);
        } else {
            $point = [];
        }
        $record->autoFix();
        $record->save();
        $this->success('添加点成功', $point);
    }

    public function update_point()
    {
        $record_id = $this->request->post('record_id');
        $point_id = $this->request->post('id');
        /** @var InspectionRecord $record */
        $record = InspectionRecord::query()->where('id', $record_id)->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $point = $record->points()->where('id', $point_id)->find();
        if (empty($point)) {
            $this->error('点不存在');
        }
        $point->is_pause = $this->request->post('is_pause', 0);
        $point->save();
        $this->success("成功");
    }

}