<?php

namespace plugin\inspection\controller\api\auth;

use plugin\inspection\controller\api\Auth;
use plugin\ticket\model\TicketVerify as Model;

class TicketVerify extends Auth
{

    public function list()
    {
        $query = Model::query()->with(['ticket'])->where(['staff_id'=>$this->staff->id]);
        $query->order('create_at', 'desc');
        $status = $this->request->get('status/i', null);
        if (is_numeric($status)) {
            $query->where('status', '=', $status);
        }
        $keyword = $this->request->get('keyword', null);
        if ($keyword) {
            $query->where('title', 'like', "%{$keyword}%");
        }
        $pageData = $query->paginate();
        $this->success('获取工单列表', $pageData);
    }

    public function detail()
    {
        $id = $this->request->get('id', null);
        $data = Model::query()->with(['ticket'])->where('staff_id', '=', $this->staff->id)->where(['id'=>$id])->find();
        if (!$data) {
            $this->error('工单不存在');
        }
        $this->success('获取工单详情', $data);
    }

    public function submit()
    {
        $data = $this->_vali([
            'ticket_id.require' => '工单ID不能为空',
            'content.require' => '工单内容不能为空',
            'is_error.in:0,1' => '请选择是否有异常',
            'imgs.default' => '',
            'work_days.default' => '',
        ]);
        $ticket = Model::query()->with(['ticket'])->where('staff_id', '=', $this->staff->id)->where(['id'=>$data['ticket_id']])->find();
        if (!$ticket) {
            $this->error('工单不存在');
        }
        unset($data['ticket_id']);
        if ($ticket->status === 1) {
            $this->error('工单已提交');
        }
        if ($ticket->status === 2) {
            $this->error('工单已关闭');
        }
        try {
            $data['status'] = 1;
            $ticket->finish_at = date('Y-m-d H:i:s');
            $ticket->save($data);
        } catch (\Exception $exception) {
            $this->error('工单提交失败');
        }
        $this->success('工单提交成功');
    }
}