<?php

namespace plugin\inspection\model;

use Cassandra\Date;
use plugin\ticket\model\TicketInspectionShare;
use plugin\ticket\model\TicketTicket;
use think\admin\Model;

class InspectionRecord extends Model
{
    public function staff()
    {
        return $this->belongsTo(InspectionStaff::class, 'staff_id', 'id');
    }

    public function points()
    {
        return $this->hasMany(InspectionRecordPoint::class, 'record_id', 'id')->order('create_at', 'asc');
    }

    public function autoFix()
    {
        $this->distance = $this->calculateDistance();
        $this->duration = $this->calculateTime();
    }

    public function calculateTime()
    {
        $points = $this->points()->select();
        $startTime = null;
        $endTime = null;
        foreach ($points as $point) {
            if ($point->is_pause) continue;
            if ($startTime === null) {
                $startTime = $point->create_at;
            }
            $endTime = $point->create_at;
        }
        if ($startTime && $endTime) {
            $start = new \DateTime($startTime);
            $end = new \DateTime($endTime);
            return $end->diff($start)->format('%H:%I:%S');
        }
        return '0:00:00';
    }

    public function calculateDistance()
    {
        $points = $this->points()->select();
        $distance = 0;
        $previousPoint = null;
        foreach ($points as $point) {
            $lat = $point->lat;
            $lng = $point->lng;
            if ($previousPoint) {
                $distance += $this->calculateDistanceBetweenPoints($previousPoint[0], $previousPoint[1], $lat, $lng);
            }
            $previousPoint = [$lat, $lng];
        }
        return $distance;
    }

    private function calculateDistanceBetweenPoints($lat1, $lng1, $lat, $lng)
    {
        $earthRadius = 6371000; // 地球半径，单位为米
        $dLat = deg2rad($lat - $lat1);
        $dLng = deg2rad($lng - $lng1);
        $lat1 = deg2rad($lat1);
        $lat = deg2rad($lat);
        $d = $earthRadius * 2 * asin(sqrt(pow(sin($dLat / 2), 2) + cos($lat1) * cos($lat) * pow(sin($dLng / 2), 2)));
        return $d;
    }

    public function ticket()
    {
        return $this->hasMany(TicketInspectionShare::class, 'record_id', 'id');
    }

}