<?php

namespace plugin\ticket\model;

use think\admin\Model;

class ApprovalInstance extends Model
{
    // 表名定义
    protected $name = 'approval_instance';

    // 自动写入时间戳
    protected $autoWriteTimestamp = 'datetime';
    protected $createTime = 'create_time';
    protected $updateTime = 'update_time';
    protected $append = ['status_text', 'current'];

    public function ticket()
    {
        return $this->belongsTo(TicketTicket::class, 'oid', 'id');
    }

    // 关联流程定义
    public function process()
    {
        return $this->belongsTo(ApprovalProcess::class, 'process_id', 'id');
    }

    // 关联审批步骤
    public function steps()
    {
        return $this->hasMany(ApprovalStep::class, 'instance_id', 'id')->with('approver');
    }

    public function getCurrentAttr($value, $data)
    {
        return $this->steps[$data['current_step']] ?? [];
    }

    // 关联审批日志
    public function logs()
    {
        return $this->hasMany(ApprovalLog::class, 'instance_id', 'id');
    }

    // 格式化流程状态
    public function getStatusTextAttr($value, $data)
    {
        $statusMap = [
            -1 => '已取消',
            0 => '进行中',
            1 => '已通过',
            2 => '已驳回',
        ];
        return $statusMap[$data['status']] ?? '未知';
    }
}